@@ -69,6 +69,10 @@ static const BuiltinColourMatrix s_matrices[] = {
       0,
       0,
       { 5902,-933,-782,-8983,16719,2354,-1402,1455,6464 } },
+    { OR_MAKE_NIKON_TYPEID(OR_TYPEID_NIKON_D1H),
+      0,
+      0,
+      { 7659, -2238, -935, -8942, 16969, 2004, -2701, 3051, 8690 } },
     { OR_MAKE_NIKON_TYPEID(OR_TYPEID_NIKON_D1X),
       0,
       0,
@@ -241,6 +245,10 @@ static const BuiltinColourMatrix s_matrices[] = {
       0,
       0,
       { 9020, -2890, -715, -4535, 12436, 2348, -934, 1919, 7086 } },
+    { OR_MAKE_NIKON_TYPEID(OR_TYPEID_NIKON_D7500),
+      0,
+      0,
+      { 8813, -3210, -1036, -4703, 12868, 2021, -1054, 1940, 6129 } },
     { OR_MAKE_NIKON_TYPEID(OR_TYPEID_NIKON_D780),
       0,
       0,
@@ -264,6 +272,10 @@ static const BuiltinColourMatrix s_matrices[] = {
       0,
       0,
       { 9369, -3195, -791, -4488, 12430, 2301, -893, 1796, 6872 } },
+    { OR_MAKE_NIKON_TYPEID(OR_TYPEID_NIKON_D850),
+      0,
+      0,
+      { 10405, -3755, -1270, -5461, 13787, 1793, -1040, 2015, 6785 } },
 
     { OR_MAKE_NIKON_TYPEID(OR_TYPEID_NIKON_D90),
       0,
@@ -350,15 +362,19 @@ static const BuiltinColourMatrix s_matrices[] = {
     { OR_MAKE_NIKON_TYPEID(OR_TYPEID_NIKON_COOLPIX_P7000),
       0,
       0,
-      { 11432,-3679,-1111,-3169,11239,2202,-791,1380,4455 } },
+      { 11432, -3679, -1111, -3169, 11239, 2202, -791, 1380, 4455 } },
     { OR_MAKE_NIKON_TYPEID(OR_TYPEID_NIKON_COOLPIX_P7100),
       0,
       0,
-      { 11053,-4269,-1024,-1976,10182,2088,-526,1263,4469 } },
+      { 11053, -4269, -1024, -1976, 10182, 2088, -526, 1263, 4469 } },
     { OR_MAKE_NIKON_TYPEID(OR_TYPEID_NIKON_COOLPIX_P7700),
       0,
       0,
-      { 10321,-3920,-931,-2750,11146,1824,-442,1545,5539 } },
+      { 10321, -3920, -931, -2750, 11146, 1824, -442, 1545, 5539 } },
+    { OR_MAKE_NIKON_TYPEID(OR_TYPEID_NIKON_COOLPIX_P7800),
+      200,
+      0,
+      { 10321, -3920, -931, -2750, 11146, 1824, -442, 1545, 5539 } },
 
     { OR_MAKE_NIKON_TYPEID(OR_TYPEID_NIKON_1_AW1),
       0,
@@ -425,6 +441,7 @@ static const BuiltinColourMatrix s_matrices[] = {
 const IfdFile::camera_ids_t NefFile::s_def[] = {
     { "NIKON D1 ", OR_MAKE_NIKON_TYPEID(OR_TYPEID_NIKON_D1) },
     { "NIKON D100 ", OR_MAKE_NIKON_TYPEID(OR_TYPEID_NIKON_D100) },
+    { "NIKON D1H", OR_MAKE_NIKON_TYPEID(OR_TYPEID_NIKON_D1H) },
     { "NIKON D1X", OR_MAKE_NIKON_TYPEID(OR_TYPEID_NIKON_D1X) },
     { "NIKON D200", OR_MAKE_NIKON_TYPEID(OR_TYPEID_NIKON_D200) },
     { "NIKON D2H", OR_MAKE_NIKON_TYPEID(OR_TYPEID_NIKON_D2H) },
@@ -466,11 +483,13 @@ const IfdFile::camera_ids_t NefFile::s_def[] = {
     { "NIKON D7100", OR_MAKE_NIKON_TYPEID(OR_TYPEID_NIKON_D7100) },
     { "NIKON D7200", OR_MAKE_NIKON_TYPEID(OR_TYPEID_NIKON_D7200) },
     { "NIKON D750", OR_MAKE_NIKON_TYPEID(OR_TYPEID_NIKON_D750) },
+    { "NIKON D7500", OR_MAKE_NIKON_TYPEID(OR_TYPEID_NIKON_D7500) },
     { "NIKON D780", OR_MAKE_NIKON_TYPEID(OR_TYPEID_NIKON_D780) },
     { "NIKON D80", OR_MAKE_NIKON_TYPEID(OR_TYPEID_NIKON_D80) },
     { "NIKON D800", OR_MAKE_NIKON_TYPEID(OR_TYPEID_NIKON_D800) },
     { "NIKON D800E", OR_MAKE_NIKON_TYPEID(OR_TYPEID_NIKON_D800E) },
     { "NIKON D810", OR_MAKE_NIKON_TYPEID(OR_TYPEID_NIKON_D810) },
+    { "NIKON D850", OR_MAKE_NIKON_TYPEID(OR_TYPEID_NIKON_D850) },
     { "NIKON D90", OR_MAKE_NIKON_TYPEID(OR_TYPEID_NIKON_D90) },
     { "NIKON Df", OR_MAKE_NIKON_TYPEID(OR_TYPEID_NIKON_DF) },
     { "NIKON Z 6", OR_MAKE_NIKON_TYPEID(OR_TYPEID_NIKON_Z6) },
@@ -494,6 +513,7 @@ const IfdFile::camera_ids_t NefFile::s_def[] = {
     { "COOLPIX P7000", OR_MAKE_NIKON_TYPEID(OR_TYPEID_NIKON_COOLPIX_P7000) },
     { "COOLPIX P7100", OR_MAKE_NIKON_TYPEID(OR_TYPEID_NIKON_COOLPIX_P7100) },
     { "COOLPIX P7700", OR_MAKE_NIKON_TYPEID(OR_TYPEID_NIKON_COOLPIX_P7700) },
+    { "COOLPIX P7800", OR_MAKE_NIKON_TYPEID(OR_TYPEID_NIKON_COOLPIX_P7800) },
     { "COOLPIX A", OR_MAKE_NIKON_TYPEID(OR_TYPEID_NIKON_COOLPIX_A) },
     { "COOLPIX A1000", OR_MAKE_NIKON_TYPEID(OR_TYPEID_NIKON_COOLPIX_A1000) },
     { "NIKON 1 J1", OR_MAKE_NIKON_TYPEID(OR_TYPEID_NIKON_1_J1) },
