@@ -43,6 +43,7 @@
 #include "rawfile_private.hpp"
 #include "io/streamclone.hpp"
 #include "jfifcontainer.hpp"
+#include "unpack.hpp"
 
 using namespace Debug;
 
@@ -66,6 +67,10 @@ static const BuiltinColourMatrix s_matrices[] = {
       0,
       0xf99,
       { 9487,-2875,-1115,-7533,15606,2010,-1618,2100,7389 } },
+    { OR_MAKE_OLYMPUS_TYPEID(OR_TYPEID_OLYMPUS_E30),
+      0,
+      0,
+      { 8144, -1861, -1111, -7763, 15894, 1929, -1865, 2542, 7607 } },
     { OR_MAKE_OLYMPUS_TYPEID(OR_TYPEID_OLYMPUS_E5),
       0,
       0,
@@ -86,6 +91,14 @@ static const BuiltinColourMatrix s_matrices[] = {
       0,
       0xf6a,
       { 8856,-2582,-1026,-7761,15766,2082,-2009,2575,7469 } },
+    { OR_MAKE_OLYMPUS_TYPEID(OR_TYPEID_OLYMPUS_E420),
+      0,
+      0,
+      { 8745, -2425, -1095, -7594, 15613, 2073, -1780, 2309, 7416 } },
+    { OR_MAKE_OLYMPUS_TYPEID(OR_TYPEID_OLYMPUS_E450),
+      0,
+      0,
+      { 8745, -2425, -1095, -7594, 15613, 2073, -1780, 2309, 7416 } },
     { OR_MAKE_OLYMPUS_TYPEID(OR_TYPEID_OLYMPUS_E500),
       0,
       0,
@@ -94,6 +107,14 @@ static const BuiltinColourMatrix s_matrices[] = {
       0,
       0xf6a,
       { 8785,-2529,-1033,-7639,15624,2112,-1783,2300,7817 } },
+    { OR_MAKE_OLYMPUS_TYPEID(OR_TYPEID_OLYMPUS_E520),
+      0,
+      0,
+      { 8343, -2322, -1020, -7596, 15635, 2048, -1748, 2269, 7287 } },
+    { OR_MAKE_OLYMPUS_TYPEID(OR_TYPEID_OLYMPUS_E600),
+      0,
+      0,
+      { 8453, -2198, -1092, -7609, 15681, 2008, -1725, 2337, 7824 } },
     { OR_MAKE_OLYMPUS_TYPEID(OR_TYPEID_OLYMPUS_E620),
       0,
       0xfaf,
@@ -130,6 +151,10 @@ static const BuiltinColourMatrix s_matrices[] = {
       0,
       0,
       { 7575,-2159,-571,-3722,11341,2725,-1434,2819,6271 } },
+    { OR_MAKE_OLYMPUS_TYPEID(OR_TYPEID_OLYMPUS_EP5),
+      0,
+      0,
+      { 8380, -2630, -639, -2887, 10725, 2496, -627, 1427, 5438 } },
     { OR_MAKE_OLYMPUS_TYPEID(OR_TYPEID_OLYMPUS_EPL1),
       0,
       0,
@@ -275,13 +300,18 @@ const struct IfdFile::camera_ids_t OrfFile::s_def[] = {
     { "E-1             ", OR_MAKE_OLYMPUS_TYPEID(OR_TYPEID_OLYMPUS_E1) },
     { "E-10        "    , OR_MAKE_OLYMPUS_TYPEID(OR_TYPEID_OLYMPUS_E10) },
     { "E-3             ", OR_MAKE_OLYMPUS_TYPEID(OR_TYPEID_OLYMPUS_E3) },
+    { "E-30            ", OR_MAKE_OLYMPUS_TYPEID(OR_TYPEID_OLYMPUS_E30) },
     { "E-5             ", OR_MAKE_OLYMPUS_TYPEID(OR_TYPEID_OLYMPUS_E5) },
     { "E-300           ", OR_MAKE_OLYMPUS_TYPEID(OR_TYPEID_OLYMPUS_E300) },
     { "E-330           ", OR_MAKE_OLYMPUS_TYPEID(OR_TYPEID_OLYMPUS_E330) },
     { "E-400           ", OR_MAKE_OLYMPUS_TYPEID(OR_TYPEID_OLYMPUS_E400) },
     { "E-410           ", OR_MAKE_OLYMPUS_TYPEID(OR_TYPEID_OLYMPUS_E410) },
+    { "E-420           ", OR_MAKE_OLYMPUS_TYPEID(OR_TYPEID_OLYMPUS_E420) },
+    { "E-450           ", OR_MAKE_OLYMPUS_TYPEID(OR_TYPEID_OLYMPUS_E450) },
     { "E-500           ", OR_MAKE_OLYMPUS_TYPEID(OR_TYPEID_OLYMPUS_E500) },
     { "E-510           ", OR_MAKE_OLYMPUS_TYPEID(OR_TYPEID_OLYMPUS_E510) },
+    { "E-520           ", OR_MAKE_OLYMPUS_TYPEID(OR_TYPEID_OLYMPUS_E520) },
+    { "E-600           ", OR_MAKE_OLYMPUS_TYPEID(OR_TYPEID_OLYMPUS_E600) },
     { "E-620           ", OR_MAKE_OLYMPUS_TYPEID(OR_TYPEID_OLYMPUS_E620) },
     { "SP350"           , OR_MAKE_OLYMPUS_TYPEID(OR_TYPEID_OLYMPUS_SP350) },
     { "SP500UZ"         , OR_MAKE_OLYMPUS_TYPEID(OR_TYPEID_OLYMPUS_SP500UZ) },
@@ -291,6 +321,7 @@ const struct IfdFile::camera_ids_t OrfFile::s_def[] = {
     { "E-P1            ", OR_MAKE_OLYMPUS_TYPEID(OR_TYPEID_OLYMPUS_EP1) },
     { "E-P2            ", OR_MAKE_OLYMPUS_TYPEID(OR_TYPEID_OLYMPUS_EP2) },
     { "E-P3            ", OR_MAKE_OLYMPUS_TYPEID(OR_TYPEID_OLYMPUS_EP3) },
+    { "E-P5            ", OR_MAKE_OLYMPUS_TYPEID(OR_TYPEID_OLYMPUS_EP5) },
     { "E-PL1           ", OR_MAKE_OLYMPUS_TYPEID(OR_TYPEID_OLYMPUS_EPL1) },
     { "E-PL2           ", OR_MAKE_OLYMPUS_TYPEID(OR_TYPEID_OLYMPUS_EPL2) },
     { "E-PL3           ", OR_MAKE_OLYMPUS_TYPEID(OR_TYPEID_OLYMPUS_EPL3) },
@@ -413,15 +444,7 @@ OrfFile::~OrfFile()
         switch(compression) {
         case IFD::COMPRESS_OLYMPUS:
             if((options & OR_OPTIONS_DONT_DECOMPRESS) == 0) {
-                OlympusDecompressor decomp((const uint8_t*)data.data(),
-                                           data.size(), m_container, x, y);
-                RawDataPtr dData = decomp.decompress();
-                if (dData) {
-                    dData->setCfaPatternType(data.mosaicInfo()->patternType());
-                    data.swap(*dData);
-                    data.setDataType(OR_DATA_TYPE_RAW);
-                    data.setDimensions(x, y);
-                }
+                err = decompress(x, y, data);
             }
             break;
         default:
@@ -431,6 +454,61 @@ OrfFile::~OrfFile()
     return err;
 }
 
+::or_error OrfFile::decompress(uint32_t x, uint32_t y, RawData& data)
+{
+    // packed bits
+    if (data.size() == (y * ((x * 12 / 8) + ((x + 2) / 10)))) {
+        // unpack with control le version of NikonPack
+        LOGDBG1("ORF: unpack with control\n");
+        RawDataPtr output(new RawData);
+
+        uint32_t current_offset = 0;
+        Unpack unpack(x, IFD::COMPRESS_OLYMPUS);
+        const size_t blocksize = unpack.block_size();
+        LOGDBG1("Block size = %lu\n", (LSIZE)blocksize);
+        LOGDBG1("dimensions (x, y) %u, %u\n", x, y);
+        auto pdata = (uint8_t*)data.data();
+
+        size_t outsize = x * y * 2;
+        uint16_t* outdata = (uint16_t*)output->allocData(outsize);
+        LOGDBG1("offset of RAW data = %u\n", current_offset);
+        do {
+
+            size_t out;
+            auto ret = unpack.unpack_le12to16(outdata, outsize,
+                                              pdata,
+                                              blocksize, out);
+            pdata += blocksize;
+            current_offset += blocksize;
+            outdata += out / 2;
+            outsize -= out;
+            if (ret != OR_ERROR_NONE) {
+                break;
+            }
+        } while(current_offset < data.size());
+
+        output->setCfaPatternType(data.mosaicInfo()->patternType());
+        data.swap(*output);
+        data.setBpc(12);
+        data.setWhiteLevel((1 << 12) - 1);
+    } else {
+
+        LOGDBG1("ORF: decompress\n");
+        // Otherwise it's compressed.
+        OlympusDecompressor decomp((const uint8_t*)data.data(),
+                                   data.size(), m_container, x, y);
+        RawDataPtr dData = decomp.decompress();
+        if (dData) {
+            dData->setCfaPatternType(data.mosaicInfo()->patternType());
+            data.swap(*dData);
+        }
+    }
+
+    data.setDataType(OR_DATA_TYPE_RAW);
+    data.setDimensions(x, y);
+    return OR_ERROR_NONE;
+}
+
 }
 }
 /*
