@@ -166,6 +166,10 @@ static const BuiltinColourMatrix s_matrices[] = {
       0,
       0,
       { 11086, -4555, -839, -3512, 11310, 2517, -815, 1341, 5940 } },
+    { OR_MAKE_FUJIFILM_TYPEID(OR_TYPEID_FUJIFILM_XA10),
+      0,
+      0,
+      { 11540, -4999, -991, -2949, 10963, 2278, -382, 1049, 5605 } },
     { OR_MAKE_FUJIFILM_TYPEID(OR_TYPEID_FUJIFILM_XA2),
       0,
       0,
@@ -346,6 +350,7 @@ const RawFile::camera_ids_t RafFile::s_def[] = {
     { "X-S1", OR_MAKE_FUJIFILM_TYPEID(OR_TYPEID_FUJIFILM_XS1) },
     { "X-S10", OR_MAKE_FUJIFILM_TYPEID(OR_TYPEID_FUJIFILM_XS10) },
     { "X-A1", OR_MAKE_FUJIFILM_TYPEID(OR_TYPEID_FUJIFILM_XA1) },
+    { "X-A10", OR_MAKE_FUJIFILM_TYPEID(OR_TYPEID_FUJIFILM_XA10) },
     { "X-A2", OR_MAKE_FUJIFILM_TYPEID(OR_TYPEID_FUJIFILM_XA2) },
     { "X-A3", OR_MAKE_FUJIFILM_TYPEID(OR_TYPEID_FUJIFILM_XA3) },
     { "X-A5", OR_MAKE_FUJIFILM_TYPEID(OR_TYPEID_FUJIFILM_XA5) },
