@@ -336,7 +336,11 @@ static const BuiltinColourMatrix s_matrices[] = {
     { OR_MAKE_LEICA_TYPEID(OR_TYPEID_LEICA_DIGILUX2),
       0,
       0,
-      { 11340,-4069,-1275,-7555,15266,2448,-2960,3426,7685 } },
+      { 11340, -4069, -1275, -7555, 15266, 2448, -2960, 3426, 7685 } },
+    { OR_MAKE_LEICA_TYPEID(OR_TYPEID_LEICA_DIGILUX3),
+      0,
+      0,
+      { 8054, -1886, -1025, -8348, 16367, 2040, -2805, 3542, 7630 } },
     { OR_MAKE_LEICA_TYPEID(OR_TYPEID_LEICA_DLUX_3),
       0,
       0,
@@ -480,6 +484,7 @@ const IfdFile::camera_ids_t Rw2File::s_def[] = {
     { "DC-TZ95", OR_MAKE_PANASONIC_TYPEID(OR_TYPEID_PANASONIC_DC_TZ95) },
 
     { "DIGILUX 2", OR_MAKE_LEICA_TYPEID(OR_TYPEID_LEICA_DIGILUX2) },
+    { "DIGILUX 3", OR_MAKE_LEICA_TYPEID(OR_TYPEID_LEICA_DIGILUX3) },
     { "D-LUX 3", OR_MAKE_LEICA_TYPEID(OR_TYPEID_LEICA_DLUX_3) },
     { "D-LUX 4", OR_MAKE_LEICA_TYPEID(OR_TYPEID_LEICA_DLUX_4) },
     { "D-LUX 5", OR_MAKE_LEICA_TYPEID(OR_TYPEID_LEICA_DLUX_5) },
@@ -683,19 +688,22 @@ uint32_t Rw2File::_getJpegThumbnailOffset(const IfdDir::Ref& dir, uint32_t & len
     void *p = data.allocData(byte_length);
     size_t real_size = m_container->fetchData(p, offset,
                                               byte_length);
-
-    if (real_size / (x * 8 / 7) == y) {
+    if (real_size < byte_length) {
+        LOGDBG1("adjusting size");
+        data.adjustSize(real_size);
+    }
+    bool packed = false;
+    if ((x * y * 2) == real_size) {
+        data.setDataType(OR_DATA_TYPE_RAW);
+    } else if ((x * y * 3 / 2) == real_size) {
+        data.setDataType(OR_DATA_TYPE_RAW);
+        packed = true;
+    } else {
         data.setDataType(OR_DATA_TYPE_COMPRESSED_RAW);
         auto v = _cfaIfd->getValue<uint16_t>(RW2_TAG_IMAGE_COMPRESSION);
         if (v) {
             data.setCompression(v.value());
         }
-    } else if (real_size < byte_length) {
-        LOGWARN("Size mismatch for data: expected %u got %lu ignoring.\n",
-                byte_length, (LSIZE)real_size);
-        return OR_ERROR_NOT_FOUND;
-    } else {
-        data.setDataType(OR_DATA_TYPE_RAW);
     }
     // It seems that they are all RGB
     auto pattern = _cfaIfd->getValue<uint16_t>(RW2_TAG_IMAGE_CFAPATTERN);
